@@ -2,14 +2,14 @@
 # Github: http://www.github.com/jasmcaus
 
 from .preprocess import preprocess_from_directory
-from .preprocess import sepTrain
+from .preprocess import sep_train
 from .preprocess import shuffle
 from .preprocess import reshape
 from .preprocess import normalize
 from .preprocess import _printTotal
 
-from .training import create_dataset
-from .training import load_dataset
+from .io import HDF5Dataset
+from .io import load_dataset
 
 from .utils import readImg
 from .utils import saveNumpy
